==> jredmine-maven-plugin-1.3-sources.jar: org/nuiton/jredmine/plugin/report/IssuesReportByCategory.java <==
/*
 * #%L
 * JRedmine :: Maven plugin
 * 
 * $Id: IssuesReportByCategory.java 186 2011-05-20 12:32:08Z tchemit $
 * $HeadURL: http://svn.nuiton.org/svn/jredmine/tags/jredmine-1.3/jredmine-maven-plugin/src/main/java/org/nuiton/jredmine/plugin/report/IssuesReportByCategory.java $
 * %%
 * Copyright (C) 2009 - 2010 Tony Chemit, CodeLutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as 
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Lesser Public License for more details.
 * 
 * You should have received a copy of the GNU General Lesser Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/lgpl-3.0.html>.
 * #L%
 */
package org.nuiton.jredmine.plugin.report;

import java.util.Map;

/**
 * Generates a report for issues from Redmine's server group by category.
 *
 * @author tchemit
 * @goal issues-report-by-category
 * @since 1.0.0
 */
public class IssuesReportByCategory extends AbstractIssuesReport {

    /**
     * Maximum number of entries to be fetched from redmine.
     * <p/>
     * <b>Note:</b> use value 0 to have no limits
     *
     * @parameter expression="${redmine.maxEntries}" default-value="100"
     * @since 1.0.0
     */
    protected int maxEntriesByCategory;

    /**
     * If you only want to show issues for the current version in the report.
     * The current version being used is <code>${project.version}</code> minus
     * any "-SNAPSHOT" suffix.
     *
     * @parameter expression="${redmine.onlyCurrentVersion}" default-value="false"
     * @since 1.0.0
     */
    protected boolean onlyCurrentVersionByCategory;

    /**
     * Sets some filters on issues to include.
     * the possible keys are :
     * <ul>
     * <li><b>version</b> : to restrict on version fixed </li>
     * <li><b>status</b> : to restrict on some status</li>
     * <li><b>priority</b> : to restrict on some priorties</li>
     * <li><b>category</b> : to restrict on some categories</li>
     * <li><b>tracker</b> : to restrict on some tracker (says type of issues)</li>
     * </ul>
     * <p/>
     * Values are Redmine's internal ids (except for the version entry
     * which use Redmine's version names).
     * <p/>
     * Multiple values can be separated by commas.
     * <p/>
     * <p/>
     * <b>Note :</b> If a value is set to empty - that means to not filter on
     * that property.
     * <p/>
     * <p/>
     * To see the internal ids, use the command :
     * <pre>
     * mvn redmine:display-data -Dtypes=&lt;entry key&gt;
     * </pre>
     *
     * @parameter
     * @since 1.0.0
     */
    protected Map<String, String> filtersByCategory;

    /**
     * Sets the column names that you want to show in the report. The columns
     * will appear in the report in the same order as you specify them here.
     * Multiple values can be separated by commas.
     * <p>
     * Valid columns are: <code>Key</code>, <code>Summary</code>,
     * <code>Status</code>, <code>Assignee</code>,
     * <code>Reporter</code>, <code>Tracker</code>, <code>Priority</code>,
     * <code>Version</code>, <code>Category</code>, <code>Created</code> and
     * <code>Updated</code>.
     * </p>
     *
     * @parameter expression="${redmine.columnNames}" default-value="Tracker,Category,Key,Summary,Status,Assignee,Version"
     * @since 2.0
     */
    protected String columnNamesByCategory;

    /**
     * A flag to skip the report.
     * <p/>
     * This can be usefull since there is no way to skip a report from an
     * inherited reportSet configuration.
     *
     * @parameter expression="${redmine.skipIssueReportByCategory}" default-value="false"
     * @since 1.0.0
     */
    protected boolean skipIssueReportByCategory;

    @Override
    protected boolean skipReport() {
        return skipIssueReportByCategory;
    }

    public IssuesReportByCategory() {
        super("category");
    }

    ///////////////////////////////////////////////////////////////////////////
    /// IssueCollectionConfiguration
    ///////////////////////////////////////////////////////////////////////////

    @Override
    public boolean isOnlyCurrentVersion() {
        return onlyCurrentVersionByCategory;
    }

    @Override
    public int getMaxEntries() {
        return maxEntriesByCategory;
    }

    ///////////////////////////////////////////////////////////////////////////
    /// AbstractIssuesReport
    ///////////////////////////////////////////////////////////////////////////

    @Override
    protected String getColumnNames() {
        return columnNamesByCategory;
    }

    @Override
    protected Map<String, String> getFilters() {
        return filtersByCategory;
    }
}

==> jredmine-maven-plugin-1.4-sources.jar: org/nuiton/jredmine/plugin/report/IssuesReportByCategory.java <==
/*
 * #%L
 * JRedmine :: Maven plugin
 * 
 * $Id: IssuesReportByCategory.java 303 2012-07-15 11:14:29Z tchemit $
 * $HeadURL: http://svn.nuiton.org/svn/jredmine/tags/jredmine-1.4/jredmine-maven-plugin/src/main/java/org/nuiton/jredmine/plugin/report/IssuesReportByCategory.java $
 * %%
 * Copyright (C) 2009 - 2012 Tony Chemit, CodeLutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as 
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Lesser Public License for more details.
 * 
 * You should have received a copy of the GNU General Lesser Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/lgpl-3.0.html>.
 * #L%
 */
package org.nuiton.jredmine.plugin.report;

import org.apache.maven.plugins.annotations.Mojo;
import org.apache.maven.plugins.annotations.Parameter;

import java.util.Map;

/**
 * Generates a report for issues from Redmine's server group by category.
 *
 * @author tchemit <chemit@codelutin.com>
 * @since 1.0.0
 */
@Mojo(name = "issues-report-by-category", requiresOnline = true, requiresProject = true, requiresReports = true)
public class IssuesReportByCategory extends AbstractIssuesReport {

    /**
     * Maximum number of entries to be fetched from redmine.
     * <p/>
     * <b>Note:</b> use value 0 to have no limits
     *
     * @since 1.0.0
     */
    @Parameter(property = "redmine.maxEntries", defaultValue = "100")
    protected int maxEntriesByCategory;

    /**
     * If you only want to show issues for the current version in the report.
     * The current version being used is <code>${project.version}</code> minus
     * any "-SNAPSHOT" suffix.
     *
     * @since 1.0.0
     */
    @Parameter(property = "redmine.onlyCurrentVersion", defaultValue = "false")
    protected boolean onlyCurrentVersionByCategory;

    /**
     * Sets some filters on issues to include.
     * the possible keys are :
     * <ul>
     * <li><b>version</b> : to restrict on version fixed </li>
     * <li><b>status</b> : to restrict on some status</li>
     * <li><b>priority</b> : to restrict on some priorties</li>
     * <li><b>category</b> : to restrict on some categories</li>
     * <li><b>tracker</b> : to restrict on some tracker (says type of issues)</li>
     * </ul>
     * <p/>
     * Values are Redmine's internal ids (except for the version entry
     * which use Redmine's version names).
     * <p/>
     * Multiple values can be separated by commas.
     * <p/>
     * <p/>
     * <b>Note :</b> If a value is set to empty - that means to not filter on
     * that property.
     * <p/>
     * <p/>
     * To see the internal ids, use the command :
     * <pre>
     * mvn redmine:display-data -Dtypes=&lt;entry key&gt;
     * </pre>
     *
     * @since 1.0.0
     */
    @Parameter
    protected Map<String, String> filtersByCategory;

    /**
     * Sets the column names that you want to show in the report. The columns
     * will appear in the report in the same order as you specify them here.
     * Multiple values can be separated by commas.
     * <p>
     * Valid columns are: <code>Key</code>, <code>Summary</code>,
     * <code>Status</code>, <code>Assignee</code>,
     * <code>Reporter</code>, <code>Tracker</code>, <code>Priority</code>,
     * <code>Version</code>, <code>Category</code>, <code>Created</code> and
     * <code>Updated</code>.
     * </p>
     *
     * @since 2.0
     */
    @Parameter(property = "redmine.columnNames", defaultValue = "Tracker,Category,Key,Summary,Status,Assignee,Version")
    protected String columnNamesByCategory;

    /**
     * A flag to skip the report.
     * <p/>
     * This can be usefull since there is no way to skip a report from an
     * inherited reportSet configuration.
     *
     * @since 1.0.0
     */
    @Parameter(property = "redmine.skipIssueReportByCategory", defaultValue = "false")
    protected boolean skipIssueReportByCategory;

    @Override
    protected boolean skipReport() {
        return skipIssueReportByCategory;
    }

    public IssuesReportByCategory() {
        super("category");
    }

    ///////////////////////////////////////////////////////////////////////////
    /// IssueCollectionConfiguration
    ///////////////////////////////////////////////////////////////////////////

    @Override
    public boolean isOnlyCurrentVersion() {
        return onlyCurrentVersionByCategory;
    }

    @Override
    public int getMaxEntries() {
        return maxEntriesByCategory;
    }

    ///////////////////////////////////////////////////////////////////////////
    /// AbstractIssuesReport
    ///////////////////////////////////////////////////////////////////////////

    @Override
    protected String getColumnNames() {
        return columnNamesByCategory;
    }

    @Override
    protected Map<String, String> getFilters() {
        return filtersByCategory;
    }
}
